========================
Funding acknowledgements
========================

.. include:: ../../../README.rst
   :start-after: inclusion-marker-acknowledgements-begin
   :end-before: inclusion-marker-acknowledgements-end
